"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UseCls = void 0;
require("reflect-metadata");
const copy_method_metadata_1 = require("../../utils/copy-method-metadata");
const cls_service_manager_1 = require("../cls-service-manager");
const cls_constants_1 = require("../cls.constants");
const cls_options_1 = require("../cls.options");
function UseCls(maybeOptions) {
    return (target, propertyKey, descriptor) => {
        const options = Object.assign(Object.assign({}, new cls_options_1.ClsDecoratorOptions()), maybeOptions);
        const cls = cls_service_manager_1.ClsServiceManager.getClsService();
        const original = descriptor.value;
        // console.log('original is', original?.toString());
        if (typeof original !== 'function') {
            throw new Error(`The @UseCls decorator can be only used on functions, but ${propertyKey.toString()} is not a function.`);
        }
        descriptor.value = function (...args) {
            var _a;
            return cls.run((_a = options.runOptions) !== null && _a !== void 0 ? _a : {}, async () => {
                var _a;
                if (options.generateId) {
                    const id = await ((_a = options.idGenerator) === null || _a === void 0 ? void 0 : _a.apply(this, args));
                    cls.set(cls_constants_1.CLS_ID, id);
                }
                if (options.setup) {
                    await options.setup.apply(this, [cls, ...args]);
                }
                if (options.initializePlugins) {
                    await cls.initializePlugins();
                }
                if (options.resolveProxyProviders) {
                    await cls.resolveProxyProviders();
                }
                return original.apply(this, args);
            });
        };
        (0, copy_method_metadata_1.copyMethodMetadata)(original, descriptor.value);
    };
}
exports.UseCls = UseCls;
//# sourceMappingURL=use-cls.decorator.js.map