import { DynamicModule, MiddlewareConsumer, NestModule, Type } from '@nestjs/common';
import { HttpAdapterHost, ModuleRef } from '@nestjs/core';
import { ClsModuleAsyncOptions, ClsModuleOptions } from './cls.options';
import { ClsModuleProxyProviderOptions } from './proxy-provider/proxy-provider.interfaces';
export declare class ClsModule implements NestModule {
    private readonly adapterHost;
    private readonly moduleRef;
    constructor(adapterHost: HttpAdapterHost, moduleRef: ModuleRef);
    private static logger;
    configure(consumer: MiddlewareConsumer): void;
    private isForRootImport;
    /**
     * Configures the CLS module in the root.
     *
     * Provides the `ClsService` for injection.
     */
    static forRoot(options?: ClsModuleOptions): DynamicModule;
    /**
     * Configures the CLS module in the root with asynchronously provided configuration.
     *
     * Provides the `ClsService` for injection.
     */
    static forRootAsync(asyncOptions: ClsModuleAsyncOptions): DynamicModule;
    /**
     * Registers the `ClsService` provider in the module
     */
    static forFeature(): DynamicModule;
    /**
     * Registers the given Class proxy providers in the module along with `ClsService`.
     */
    static forFeature(...proxyProviderClasses: Array<Type>): DynamicModule;
    /**
     * Registers the given Class or Factory proxy providers in the module along with `ClsService`.
     *
     * If used with `global: true`, makes the proxy provider available globally.
     */
    static forFeatureAsync(options: ClsModuleProxyProviderOptions): DynamicModule;
    private static createProxyClassProviders;
    private static getProviders;
    private static clsMiddlewareOptionsFactory;
    private static clsGuardOptionsFactory;
    private static clsInterceptorOptionsFactory;
    private static clsGuardFactory;
    private static clsInterceptorFactory;
}
